#!/bin/csh -f

rm -f randgraph el2csr
gcc -std=c11 -Wall -Wextra -g        -o randgraph randgraph.c
gcc -std=c11 -Wall -Wextra -g -DTEST -o el2csr    el2csr.c

set i = 1
while ($i <= 1000)
    echo 'BEGIN test' $i `date` `date +%s.%N`
    rm -f out_edge_list.txt
    # generate random graph, remove duplicate edges
    valgrind -q ./randgraph 1000 10000 $i | sort -k 1,1n -k 2,2n | uniq > graph.$i
    # randomize edge list
    shuf < graph.$i > graph.shuf.$i
    # the max vertexID we get might by chance be less than we requested
    set V = `gawk '{if($1>m)m=$1;if($2>m)m=$2}END{print m}' graph.shuf.$i`
    # de-duplication might reduce the number of edges
    set E = `wc -l < graph.shuf.$i`
    # run CSR program, which will dump edge list to file that it creates
    valgrind -q ./el2csr $V $E graph.shuf.$i > /dev/null
    # check that sorted de-duplicated input edge list is identical to
    # edge list dumped by CSR program
    set C1 = `md5sum < graph.$i          | gawk '{print $1}'`
    set C2 = `md5sum < out_edge_list.txt | gawk '{print $1}'`
    if ($C1 != $C2) then
        echo 'ERROR:  output mismatch'
        exit
    endif
    # clean up
    rm -f graph.$i graph.shuf.$i out_edge_list.txt
    echo '  END test' $i `date` `date +%s.%N` $V $E $C1
    @ i ++
end

rm -f randgraph el2csr

